"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.downloadAndExtractExample = exports.downloadAndExtractRepo = exports.existsInRepo = exports.hasRepo = exports.getRepoInfo = exports.isUrlOk = void 0;
const got_1 = __importDefault(require("got"));
const tar_1 = __importDefault(require("tar"));
const stream_1 = require("stream");
const util_1 = require("util");
const pipeline = (0, util_1.promisify)(stream_1.Stream.pipeline);
async function isUrlOk(url) {
    const res = await got_1.default.head(url).catch((e) => e);
    return res.statusCode === 200;
}
exports.isUrlOk = isUrlOk;
async function getRepoInfo(url, examplePath) {
    const [, username, name, t, _branch, ...file] = url.pathname.split('/');
    const filePath = examplePath ? examplePath.replace(/^\//, '') : file.join('/');
    if (t === undefined) {
        const infoResponse = await (0, got_1.default)(`https://api.github.com/repos/${username}/${name}`).catch((e) => e);
        if (infoResponse.statusCode !== 200) {
            return;
        }
        const info = JSON.parse(infoResponse.body);
        return { username, name, branch: info['default_branch'], filePath };
    }
    const branch = examplePath
        ? `${_branch}/${file.join('/')}`.replace(new RegExp(`/${filePath}|/$`), '')
        : _branch;
    if (username && name && branch && t === 'tree') {
        return { username, name, branch, filePath };
    }
}
exports.getRepoInfo = getRepoInfo;
function hasRepo({ username, name, branch, filePath, }) {
    const contentsUrl = `https://api.github.com/repos/${username}/${name}/contents`;
    const packagePath = `${filePath ? `/${filePath}` : ''}/package.json`;
    return isUrlOk(contentsUrl + packagePath + `?ref=${branch}`);
}
exports.hasRepo = hasRepo;
function existsInRepo(nameOrUrl) {
    try {
        const url = new URL(nameOrUrl);
        return isUrlOk(url.href);
    }
    catch (_a) {
        return isUrlOk(`https://api.github.com/repos/steedos/steedos-examples/contents/${encodeURIComponent(nameOrUrl)}`);
    }
}
exports.existsInRepo = existsInRepo;
function downloadAndExtractRepo(root, { username, name, branch, filePath }) {
    return pipeline(got_1.default.stream(`https://codeload.github.com/${username}/${name}/tar.gz/${branch}`), tar_1.default.extract({ cwd: root, strip: filePath ? filePath.split('/').length + 1 : 1 }, [`${name}-${branch.replace(/\//g, '-')}${filePath ? `/${filePath}` : ''}`]));
}
exports.downloadAndExtractRepo = downloadAndExtractRepo;
function downloadAndExtractExample(root, name) {
    if (name === '__internal-testing-retry') {
        throw new Error('This is an internal example for testing the CLI.');
    }
    return pipeline(got_1.default.stream('https://codeload.github.com/steedos/steedos-examples/tar.gz/main'), tar_1.default.extract({ cwd: root, strip: 2 }, [`steedos-examples-main/${name}`]));
}
exports.downloadAndExtractExample = downloadAndExtractExample;
//# sourceMappingURL=examples.js.map