"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.install = void 0;
const chalk_1 = __importDefault(require("chalk"));
const cross_spawn_1 = __importDefault(require("cross-spawn"));
function install(root, dependencies, { packageManager, isOnline, devDependencies }) {
    const npmFlags = [];
    const yarnFlags = [];
    return new Promise((resolve, reject) => {
        let args;
        let command = packageManager;
        const useYarn = packageManager === 'yarn';
        if (dependencies && dependencies.length) {
            if (useYarn) {
                args = ['add', '--exact'];
                if (!isOnline)
                    args.push('--offline');
                args.push('--cwd', root);
                if (devDependencies)
                    args.push('--dev');
                args.push(...dependencies);
            }
            else {
                args = ['install', '--save-exact'];
                args.push(devDependencies ? '--save-dev' : '--save');
                args.push(...dependencies);
            }
        }
        else {
            args = ['install'];
            if (!isOnline) {
                console.log(chalk_1.default.yellow('You appear to be offline.'));
                if (useYarn) {
                    console.log(chalk_1.default.yellow('Falling back to the local Yarn cache.'));
                    console.log();
                    args.push('--offline');
                }
                else {
                    console.log();
                }
            }
        }
        if (useYarn) {
            args.push(...yarnFlags);
        }
        else {
            args.push(...npmFlags);
        }
        const child = (0, cross_spawn_1.default)(command, args, {
            stdio: 'inherit',
            env: Object.assign(Object.assign({}, process.env), { ADBLOCK: '1', DISABLE_OPENCOLLECTIVE: '1' }),
        });
        child.on('close', (code) => {
            if (code !== 0) {
                reject({ command: `${command} ${args.join(' ')}` });
                return;
            }
            resolve();
        });
    });
}
exports.install = install;
//# sourceMappingURL=install.js.map